{% extends "base.html" %}
{% load i18n %}
{% load uni_form_tags %}

{% block title %}{% trans "Edit" %}{% endblock %}

{% block main %}
<h1 id="id_title_preview">{{ object.title }}</h1>

                <div id='wmd-preview-area'></div>
{% endblock %}

{% block sidebar %}

<h1>{% trans "Edit" %}</h1>

<form action="" method="post" class="uniForm">
    <fieldset class="blockLabels">
        {% csrf_token %}
        {{ form|as_uni_form }}
    </fieldset>
    <div class="buttonHolder">
        <button type="submit" name="submit" class="primaryAction" id="submit_new_entry">{% trans "Save" %}</button>
    </div>
</form>
{% endblock sidebar %}

{% block footer_include %}
{{ form.media }}
{% endblock %}
